import React, { useContext, useState } from 'react';
import domtoimage from 'dom-to-image';
import { ImageType } from "../helpers/constants";
import { ChartContainerContext } from "../helpers/ChartContainerProvider";

interface DownloadImageChartProps {
    filename: string;
}

const DownloadImageChartButton: React.FC<DownloadImageChartProps> = ({ filename }) => {
    const chartContainerRef = useContext(ChartContainerContext);
    const [exportType, setExportType] = useState<ImageType>(ImageType.PNG);

    const downloadChartAsImage = async () => {
        if (chartContainerRef?.current) {
            const scale = 1;

            const commonStyle = {
                transform: `scale(${scale})`,
                'transform-origin': 'top left',
                background: 'white'
            };

            let dataUrl;
            switch (exportType) {
                case ImageType.JPEG:
                    dataUrl = await domtoimage.toJpeg(chartContainerRef.current, {
                        quality: 0.95,
                        style: commonStyle
                    });
                    break;
                case ImageType.SVG:
                    dataUrl = await domtoimage.toSvg(chartContainerRef.current, {
                        style: commonStyle
                    });
                    break;
                case ImageType.PNG:
                default:
                    dataUrl = await domtoimage.toPng(chartContainerRef.current, {
                          style: commonStyle
                    });
                    break;
            }

            const link = document.createElement('a');
            link.href = typeof dataUrl === 'string' ? dataUrl : URL.createObjectURL(dataUrl);
            link.download = `${filename}.${exportType}`;

            document.body.appendChild(link);
            link.click();
            document.body.removeChild(link);
        }
    }

    return (
        <>
            <select value={exportType} onChange={(e) => setExportType(e.target.value as ImageType)}>
                <option value={ImageType.PNG}>PNG</option>
                <option value={ImageType.JPEG}>JPEG</option>
                <option value={ImageType.SVG}>SVG</option>
            </select>
            <button onClick={downloadChartAsImage}>Download Chart</button>
        </>
    );
}

export default DownloadImageChartButton;
