import { useEffect, useMemo, useState } from "react";
import { Nren, NrenAndYearDatapoint } from "../Schema";
import { usePreview } from "./usePreview";


function getYearsAndNrens(sourceData: NrenAndYearDatapoint[]) {
    const years = new Set<number>();
    const nrenMap = new Map<string, Nren>();
    sourceData.forEach(datapoint => {
        years.add(datapoint.year);
        nrenMap.set(datapoint.nren, { name: datapoint.nren, country: datapoint.nren_country });
    });
    return { years: years, nrens: nrenMap };
}


export function useData<Datatype extends NrenAndYearDatapoint>(url, setFilterSelection) {

    const [data, setData] = useState<Datatype[]>([]);

    const preview = usePreview();
    const loadUrl = url + (preview ? '?preview' : '');

    useEffect(() => {
        fetch(loadUrl)
            .then(response => response.json())
            .then(json => {
                setData(json);
                // filter fallback for when nothing is selected (only last year for all nrens)
                const { years, nrens } = getYearsAndNrens(json);
                setFilterSelection(previous => {
                    const visibleYears = previous.selectedYears.filter(year => years.has(year));
                    const newSelectedYears = visibleYears.length ? previous.selectedYears : [Math.max(...years)];
                    const visibleNrens = previous.selectedNrens.filter(nren => nrens.has(nren));
                    const newSelectedNrens = visibleNrens.length ? previous.selectedNrens : [...nrens.keys()];
                    return { selectedYears: newSelectedYears, selectedNrens: newSelectedNrens };
                });
            });
    }, [loadUrl, setFilterSelection]);

    const { years, nrens } = useMemo(
        () => getYearsAndNrens(data),
        [data]
    );

    return {data: data, years: years, nrens: nrens};

}
