import React, { ReactElement } from "react";
import { Container, Row } from "react-bootstrap";
import CollapsibleBox from "../components/CollapsibleBox";
import PageHeader from "../components/global/PageHeader"
import Banner from "../components/global/Banner";
import { Link } from "react-router-dom";
import { Sections } from "../helpers/constants";
import { usePreview } from "../helpers/usePreview";

function CompendiumData(): ReactElement {
    usePreview();

    return (
        <main className="grow">
            <PageHeader type={'data'}/>
            <Banner type={'data'}>
                <p className="wordwrap">
                    The GÉANT Compendium provides an authoritative reference source for anyone with an
                    interest in the development of research and education networking in Europe and beyond.
                    Published since 2001, the Compendium provides information on key areas such as users,
                    services, traffic, budget and staffing.
                </p>
            </Banner>

            <Container className="pt-5">
                <Row>
                    <div className="center">

                        <CollapsibleBox title={Sections.Organisation}>
                            <div className="collapsible-column">

                                <Row>
                                    <Link to="/budget" className="link-text-underline">
                                        <span>Budget of NRENs per Year</span>
                                    </Link>
                                </Row>

                                <Row>
                                    <Link to="/funding" className="link-text-underline">
                                        <span>Income Source of NRENs per Year</span>
                                    </Link>
                                </Row>

                                <Row>
                                    <Link to="/charging" className="link-text-underline">
                                        <span>Charging Mechanism of NRENs per Year</span>
                                    </Link>
                                </Row>

                                <Row>
                                    <Link to="/data/roles" className="link-text-underline">
                                        <span>Roles of NREN employees</span>
                                    </Link>
                                </Row>
                                <Row>
                                    <Link to="/data/employment" className="link-text-underline">
                                        <span>Types of employment for NRENs</span>
                                    </Link>
                                </Row>
                                <Row>
                                    <Link to="/suborganisations" className="link-text-underline">
                                        <span>NREN Suborganisations</span>
                                    </Link>
                                </Row>
                                <Row>
                                    <Link to="/parentorganisation" className="link-text-underline">
                                        <span>NREN Parent Organisations</span>
                                    </Link>
                                </Row>
                                <Row>
                                    <Link to="/ec-projects" className="link-text-underline">
                                        <span>NREN Involvement in European Commission Projects</span>
                                    </Link>
                                </Row>

                            </div>
                        </CollapsibleBox>

                        <CollapsibleBox title={Sections.Policy} startCollapsed>
                            <div className="collapsible-column">

                                <Row>
                                    <Link to="/policy" className="link-text-underline">
                                        <span>NREN Policies</span>
                                    </Link>
                                </Row>

                            </div>
                        </CollapsibleBox>

                        <CollapsibleBox title={Sections.ConnectedUsers} startCollapsed>
                            <div className="collapsible-column">
                                <Row>
                                    <Link to="/institutions-urls" className="link-text-underline">
                                        <span>Connected Institutions URLs</span>
                                    </Link>
                                </Row>                            </div>
                        </CollapsibleBox>
                        <CollapsibleBox title={Sections.Network} startCollapsed>
                            <div className="collapsible-column">
                                <Row>
                                    <Link to="/traffic-volume" className="link-text-underline">
                                        <span>Total yearly traffic volume per NREN</span>
                                    </Link>
                                </Row>
                            </div>
                        </CollapsibleBox>
                        <CollapsibleBox title={Sections.Services} startCollapsed>
                            <div className="collapsible-column">
                                <Row>
                                    <Link to="/network-services" className="link-text-underline">
                                        <span>Network services</span>
                                    </Link>
                                </Row>
                                <Row>
                                    <Link to="/isp-support-services" className="link-text-underline">
                                        <span>ISP support services</span>
                                    </Link>
                                </Row>
                                <Row>
                                    <Link to="/security-services" className="link-text-underline">
                                        <span>Security services</span>
                                    </Link>
                                </Row>
                                <Row>
                                    <Link to="/identity-services" className="link-text-underline">
                                        <span>Identity services</span>
                                    </Link>
                                </Row>
                                <Row>
                                    <Link to="/collaboration-services" className="link-text-underline">
                                        <span>Collaboration services</span>
                                    </Link>
                                </Row>
                                <Row>
                                    <Link to="/multimedia-services" className="link-text-underline">
                                        <span>Multimedia services</span>
                                    </Link>
                                </Row>
                                <Row>
                                    <Link to="/storage-and-hosting-services" className="link-text-underline">
                                        <span>Storage and hosting services</span>
                                    </Link>
                                </Row>
                                <Row>
                                    <Link to="/professional-services" className="link-text-underline">
                                        <span>Professional services</span>
                                    </Link>
                                </Row>
                            </div>
                        </CollapsibleBox>
                    </div>

                </Row>
            </Container>
        </main>
    );
}

export default CompendiumData;
