import React, { useContext } from 'react';
import {Row, Table} from "react-bootstrap";

import { ECProject } from "../Schema";
import { createECProjectsDataLookup } from '../helpers/dataconversion';
import DataPage from '../components/DataPage';
import Filter from "../components/graphing/Filter"
import {ExportType, Sections} from '../helpers/constants';
import DownloadDataButton from "../components/DownloadDataButton";
import { FilterSelectionContext } from '../helpers/FilterSelectionProvider';
import DownloadImageChartButton from "../components/DownloadImageChartButton";
import ChartContainer from "../components/graphing/ChartContainer";
import { useData } from '../helpers/useData';


function getJSXFromMap(data: Map<string, Map<number, ECProject[]>>) {
    return Array.from(data.entries()).map(([nren, nrenMap]) => {
        return Array.from(nrenMap.entries()).map(([year, projects], yearIndex) => (
            <tr key={nren + year} className='dotted-border'>
                <td className='pt-3 nren-column text-nowrap'>{yearIndex == 0 && nren}</td>
                <td className='pt-3 year-column'>{year}</td>
                <td className='pt-3 blue-column'>
                    <ul>
                        {projects.map(project => (
                            <li key={project.project}>{project.project}</li>
                        ))}
                    </ul>
                </td>
            </tr>
        ))
    })
}

function ECProjects() {
    const {filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const {data: projectData, years, nrens} = useData<ECProject>('/api/ec-project/', setFilterSelection);

    const selectedData = (projectData).filter(project =>
        filterSelection.selectedYears.includes(project.year) && filterSelection.selectedNrens.includes(project.nren)
    );
    const projectDataByYear = createECProjectsDataLookup(selectedData);

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
    />

    return (
        <DataPage title="NREN Involvement in European Commission Projects" 
        description='The table shows the NRENs involvement in European Commission Projects Membership. By selecting multiple
        year and NRENs, the table can be used to compare the NRENs involvement in European Commission Projects Membership'
        category={Sections.Organisation} filter={filterNode}>
            <>
                <Row>
                    <DownloadDataButton data={projectData} filename="nren_involvement_in_european_commission_projects.csv" exportType={ExportType.CSV}/>
                    <DownloadDataButton data={projectData} filename="nren_involvement_in_european_commission_projects.xlsx" exportType={ExportType.EXCEL}/>
                </Row>
                <DownloadImageChartButton filename="nren_involvement_in_european_commission_projects"/>
                <ChartContainer>
                    <Table borderless className='compendium-table'>
                        <thead>
                        <tr>
                            <th className='nren-column'>NREN</th>
                            <th className='year-column'>Year</th>
                            <th className='blue-column'>EC Project Membership</th>
                        </tr>
                        </thead>
                        <tbody>
                        {getJSXFromMap(projectDataByYear)}
                        </tbody>
                    </Table>
                </ChartContainer>
            </>
        </DataPage>
    )
}
export default ECProjects;
