import logging

from flask import Blueprint, jsonify

from compendium_v2.db.presentation_models import NrenStaff
from compendium_v2.routes import common
from typing import Any


routes = Blueprint('staff', __name__)
logger = logging.getLogger(__name__)

STAFF_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',

    'definitions': {
        'staff': {
            'type': 'object',
            'properties': {
                'nren': {'type': 'string'},
                'nren_country': {'type': 'string'},
                'year': {'type': 'integer'},
                'permanent_fte': {'type': 'number'},
                'subcontracted_fte': {'type': 'number'},
                'technical_fte': {'type': 'number'},
                'non_technical_fte': {'type': 'number'}
            },
            'required': ['nren', 'nren_country', 'year',
                         'permanent_fte', 'subcontracted_fte', 'technical_fte', 'non_technical_fte'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/staff'}
}


@routes.route('/', methods=['GET'])
@common.require_accepts_json
def staff_view() -> Any:
    """
    handler for /api/staff/ requests

    response will be formatted as:

    .. asjson::
        compendium_v2.routes.staff.STAFF_RESPONSE_SCHEMA

    :return:
    """

    def _extract_data(entry: NrenStaff):
        return {
            'nren': entry.nren.name,
            'nren_country': entry.nren.country,
            'year': entry.year,
            'permanent_fte': float(entry.permanent_fte),
            'subcontracted_fte': float(entry.subcontracted_fte),
            'technical_fte': float(entry.technical_fte),
            'non_technical_fte': float(entry.non_technical_fte)
        }

    entries = [_extract_data(entry) for entry in common.get_data(NrenStaff)]
    return jsonify(entries)
