import json
import jsonschema
from compendium_v2 import db
from compendium_v2.db.presentation_models import PreviewYear
from compendium_v2.routes.budget import BUDGET_RESPONSE_SCHEMA


def test_budget_response(client, test_budget_data):
    rv = client.get(
        '/api/budget/',
        headers={'Accept': ['application/json']})
    assert rv.status_code == 200
    result = json.loads(rv.data.decode('utf-8'))
    jsonschema.validate(result, BUDGET_RESPONSE_SCHEMA)
    assert result


def test_budget_response_preview(app, client, test_budget_data, mocked_admin_user):
    rv = client.get(
        '/api/budget/',
        headers={'Accept': ['application/json']})
    assert rv.status_code == 200
    result = json.loads(rv.data.decode('utf-8'))
    jsonschema.validate(result, BUDGET_RESPONSE_SCHEMA)
    assert any([datapoint['year'] == 2021 for datapoint in result])

    with app.app_context():
        db.session.add(PreviewYear(year=2021))
        db.session.commit()

    rv = client.get(
        '/api/budget/?preview',
        headers={'Accept': ['application/json']})
    assert rv.status_code == 200
    result = json.loads(rv.data.decode('utf-8'))
    jsonschema.validate(result, BUDGET_RESPONSE_SCHEMA)
    assert any([datapoint['year'] == 2021 for datapoint in result])

    rv = client.get(
        '/api/budget/',
        headers={'Accept': ['application/json']})
    assert rv.status_code == 200
    result = json.loads(rv.data.decode('utf-8'))
    jsonschema.validate(result, BUDGET_RESPONSE_SCHEMA)
    assert all([datapoint['year'] != 2021 for datapoint in result])
